searchData={"items":[{"type":"module","title":"Flatbuffer","doc":"Flatbuffer binary serialization for Elixir.\n\nProvides functions to read from and write to Flatbuffer binaries using schema definitions.\nSupports direct access to nested data without parsing the entire buffer.","ref":"Flatbuffer.html"},{"type":"module","title":"Usage - Flatbuffer","doc":"# Read/Write\n    {:ok, data} = Flatbuffer.read(buffer, schema)\n    binary = Flatbuffer.to_binary(map, schema)\n\n    # Direct access\n    {:ok, value} = Flatbuffer.get(buffer, [:table, :field], schema)\n\n    # With schema file\n    def YourThing do\n      use Flatbuffer, file: \"schema.fbs\"\n    end\n\n    # Read/Write\n    {:ok, data} = YourThing.read(buffer)\n    binary = YourThing.to_binary(map)","ref":"Flatbuffer.html#module-usage"},{"type":"macro","title":"Flatbuffer.__using__/1","doc":"Generates schema-aware functions (read, get, to_iolist, etc.) in the caller module.\nOptions:\n  * :file - Required schema file path.\n  * :path - Base path for schema includes.","ref":"Flatbuffer.html#__using__/1"},{"type":"function","title":"Flatbuffer.get/3","doc":"Retrieves a value from a path without decoding the entire buffer.\nReturns {:ok, value} or {:error, :index_out_of_range}.","ref":"Flatbuffer.html#get/3"},{"type":"function","title":"Flatbuffer.get!/3","doc":"Same as get/3 but raises on error.","ref":"Flatbuffer.html#get!/3"},{"type":"function","title":"Flatbuffer.read/2","doc":"Reads a Flatbuffer into a map using the given schema.\nReturns {:ok, map} or {:error, reason}.","ref":"Flatbuffer.html#read/2"},{"type":"function","title":"Flatbuffer.read!/2","doc":"Same as read/2 but raises on error.","ref":"Flatbuffer.html#read!/2"},{"type":"function","title":"Flatbuffer.to_binary/2","doc":"Serializes a map into a Flatbuffer binary using the schema.","ref":"Flatbuffer.html#to_binary/2"},{"type":"function","title":"Flatbuffer.to_iolist/2","doc":"Serializes a map into a Flatbuffer iolist using the schema.","ref":"Flatbuffer.html#to_iolist/2"},{"type":"module","title":"Flatbuffer.Schema","doc":"Schema definition and parser for FlatBuffers.\n\nHandles parsing and processing of FlatBuffer schema files (.fbs),\nincluding type definitions, namespaces, and includes. Supports:\n\n- Tables, structs, enums, and unions\n- Basic types (bool, int, float, string, etc.)\n- Vectors and references\n- Schema includes and namespaces\n- File identifiers","ref":"Flatbuffer.Schema.html"},{"type":"module","title":"Example - Flatbuffer.Schema","doc":"{:ok, schema} = Schema.from_file(\"schema.fbs\")\n    # or\n    {:ok, schema} = Schema.from_string(schema_string)\n\n    # Optionally, you can supply a resolver for includes\n    {:ok, schema} = Schema.from_file(\"schema.fbs\", resolver: &File.read/1)","ref":"Flatbuffer.Schema.html#module-example"},{"type":"function","title":"Flatbuffer.Schema.decorate/1","doc":"","ref":"Flatbuffer.Schema.html#decorate/1"},{"type":"function","title":"Flatbuffer.Schema.decorate_field/1","doc":"","ref":"Flatbuffer.Schema.html#decorate_field/1"},{"type":"function","title":"Flatbuffer.Schema.decorate_field/2","doc":"","ref":"Flatbuffer.Schema.html#decorate_field/2"},{"type":"function","title":"Flatbuffer.Schema.decorate_referenced_field/2","doc":"","ref":"Flatbuffer.Schema.html#decorate_referenced_field/2"},{"type":"type","title":"Flatbuffer.Schema.enum_def/0","doc":"","ref":"Flatbuffer.Schema.html#t:enum_def/0"},{"type":"type","title":"Flatbuffer.Schema.enum_name/0","doc":"","ref":"Flatbuffer.Schema.html#t:enum_name/0"},{"type":"type","title":"Flatbuffer.Schema.field_name/0","doc":"","ref":"Flatbuffer.Schema.html#t:field_name/0"},{"type":"function","title":"Flatbuffer.Schema.fields_and_indices/3","doc":"","ref":"Flatbuffer.Schema.html#fields_and_indices/3"},{"type":"type","title":"Flatbuffer.Schema.from_errors/0","doc":"","ref":"Flatbuffer.Schema.html#t:from_errors/0"},{"type":"function","title":"Flatbuffer.Schema.from_file/2","doc":"Reads and parses a FlatBuffer schema from a file.","ref":"Flatbuffer.Schema.html#from_file/2"},{"type":"function","title":"Parameters - Flatbuffer.Schema.from_file/2","doc":"- `file_name` (String.t()): The path to the schema file.\n  - `opts` ([resolver: resolver_fn()]): Optional keyword list of options.\n    - `:resolver` (resolver_fn()): A function to resolve imports or includes within the schema.","ref":"Flatbuffer.Schema.html#from_file/2-parameters"},{"type":"function","title":"Returns - Flatbuffer.Schema.from_file/2","doc":"- The parsed schema, or an error tuple if the schema could not be parsed.","ref":"Flatbuffer.Schema.html#from_file/2-returns"},{"type":"function","title":"Examples - Flatbuffer.Schema.from_file/2","doc":"iex> Flatbuffer.Schema.from_file(\"path/to/schema.fbs\")\n    {:ok, schema}\n\n    iex> Flatbuffer.Schema.from_file(\"path/to/schema.fbs\", resolver: &my_resolver/1)\n    {:ok, schema}","ref":"Flatbuffer.Schema.html#from_file/2-examples"},{"type":"function","title":"Flatbuffer.Schema.from_string/2","doc":"Parses a FlatBuffer schema from a string.","ref":"Flatbuffer.Schema.html#from_string/2"},{"type":"function","title":"Parameters - Flatbuffer.Schema.from_string/2","doc":"- `string` (String.t()): The FlatBuffer schema as a string.\n  - `opts` ([resolver: resolver_fn()]): Optional keyword list of options.\n    - `:resolver` (resolver_fn()): A function used to resolve schema dependencies.","ref":"Flatbuffer.Schema.html#from_string/2-parameters"},{"type":"function","title":"Returns - Flatbuffer.Schema.from_string/2","doc":"A parsed schema.","ref":"Flatbuffer.Schema.html#from_string/2-returns"},{"type":"function","title":"Examples - Flatbuffer.Schema.from_string/2","doc":"iex(1)> schema = \"\"\"\n  ...(1)> table Table {\n  ...(1)>   field: int;\n  ...(1)> }\n  ...(1)>\n  ...(1)> root_type Table;\n  ...(1)> \"\"\"\n  iex(2)> {:ok, parsed_schema} = Flatbuffer.Schema.from_string(schema)","ref":"Flatbuffer.Schema.html#from_string/2-examples"},{"type":"function","title":"Flatbuffer.Schema.index_offset/2","doc":"","ref":"Flatbuffer.Schema.html#index_offset/2"},{"type":"function","title":"Flatbuffer.Schema.is_referenced?/1","doc":"","ref":"Flatbuffer.Schema.html#is_referenced?/1"},{"type":"type","title":"Flatbuffer.Schema.resolver_fn/0","doc":"","ref":"Flatbuffer.Schema.html#t:resolver_fn/0"},{"type":"type","title":"Flatbuffer.Schema.struct_def/0","doc":"","ref":"Flatbuffer.Schema.html#t:struct_def/0"},{"type":"type","title":"Flatbuffer.Schema.t/0","doc":"","ref":"Flatbuffer.Schema.html#t:t/0"},{"type":"type","title":"Flatbuffer.Schema.table_def/0","doc":"","ref":"Flatbuffer.Schema.html#t:table_def/0"},{"type":"function","title":"Flatbuffer.Schema.table_options/2","doc":"","ref":"Flatbuffer.Schema.html#table_options/2"},{"type":"type","title":"Flatbuffer.Schema.type_def/0","doc":"","ref":"Flatbuffer.Schema.html#t:type_def/0"},{"type":"type","title":"Flatbuffer.Schema.type_name/0","doc":"","ref":"Flatbuffer.Schema.html#t:type_name/0"},{"type":"type","title":"Flatbuffer.Schema.type_ref/0","doc":"","ref":"Flatbuffer.Schema.html#t:type_ref/0"},{"type":"type","title":"Flatbuffer.Schema.union_def/0","doc":"","ref":"Flatbuffer.Schema.html#t:union_def/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}